# aind-dataverse-service-client

## aind-dataverse-service

Service to pull data from Allen Institute's Dataverse database.



This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.3
- Package version: 0.0.3
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import aind_dataverse_service_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import aind_dataverse_service_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import aind_dataverse_service_client
from aind_dataverse_service_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = aind_dataverse_service_client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with aind_dataverse_service_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = aind_dataverse_service_client.DefaultApi(api_client)
    entity_set_table_name = 'cr138_projects' # str | The entity set name of the table to fetch

    try:
        # Get Table
        api_response = api_instance.get_table(entity_set_table_name)
        print("The response of DefaultApi->get_table:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->get_table: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**get_table**](docs/DefaultApi.md#get_table) | **GET** /tables/{entity_set_table_name} | Get Table
*DefaultApi* | [**get_table_info**](docs/DefaultApi.md#get_table_info) | **GET** /tables | Get Table Info
*HealthcheckApi* | [**get_health**](docs/HealthcheckApi.md#get_health) | **GET** /healthcheck | Perform a Health Check


## Documentation For Models

 - [EntityTableRow](docs/EntityTableRow.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [HealthCheck](docs/HealthCheck.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




